@@ -5,7 +5,7 @@ import os
 import sys
 import marshal
 import time
-from datetime import datetime, date
+from datetime import datetime, date, timedelta
 
 
 md = marshal.dumps
@@ -293,17 +293,19 @@ class UnicodeProperty(BaseProperty):
 
 class DateTimeProperty(BaseProperty):
     def encode(self, value):
-        return time.mktime(value.timetuple()) + value.microsecond / 1000000.0
+        delta = value - value.replace(hour=0, minute=0, second=0, microsecond=0)
+        return value.toordinal(), delta.seconds, delta.microseconds
+
     def decode(self, value):
-        return datetime.fromtimestamp(value)
+        return datetime.fromordinal(value[0]) + timedelta(
+            seconds=value[1], microseconds=value[2])
 
 
 class DateProperty(BaseProperty):
     def encode(self, value):
-        return int(time.mktime((
-            value.year, value.month, value.day, 0, 0, 0, 0, 0, 0)))
+        return value.toordinal()
     def decode(self, value):
-        return date.fromtimestamp(value)
+        return date.fromordinal(value)
 
 
 class CompressedStringProperty(BaseProperty):
